# wikitude_studio_api_client

Wikitude Studio API
- API version: 3.0.0
  - Build date: 2021-09-01T07:29:43.930Z[GMT]

The Wikitude Studio API is a RESTful API which is used to
* organize and manipulate projects and its targets
* create wtc/wto files which can be used to create trackers in the Wikitude SDK with the JavaScript API
* generate/publish a cloud archive to the cloud recognition service (image targets only)

Download API clients:
* [`OpenAPI 3.0`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-openapi.zip)
* [`JavaScript`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-javascript.zip)
* [`Python`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-python.zip)
* [`PHP`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-php.zip)
* [`TypeScript (NodeJS)`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-typescript-node.zip)
* [`Java`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-java.zip)
* [`Ruby`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-ruby.zip)
* [`C# .NET Core`](https://www.wikitude.com/external/doc/documentation/studio-api/clients/wikitude_studio_api_client-csharp-netcore.zip)

This technical reference formally explains various API endpoints.
Visit the [`Studio API documentation`](https://www.wikitude.com/external/doc/documentation/studio/) for a more general description.



*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*


## Requirements

Building the API client library requires:
1. Java 1.7+
2. Maven/Gradle

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>wikitude_studio_api_client</artifactId>
  <version>3.0.0</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "org.openapitools:wikitude_studio_api_client:3.0.0"
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/wikitude_studio_api_client-3.0.0.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.AccountApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://api-eu.wikitude.com/cloudrecognition");

    AccountApi apiInstance = new AccountApi(defaultClient);
    String xVersion = "3"; // String | The version of the API to be used. Must be set to 3.
    String xToken = "xToken_example"; // String | Your Manager Token.
    try {
      GetAccountInfoResponse result = apiInstance.getAccount(xVersion, xToken);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling AccountApi#getAccount");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**getAccount**](docs/AccountApi.md#getAccount) | **GET** /account | Get account information
*HeatmapApi* | [**generateHeatmap**](docs/HeatmapApi.md#generateHeatmap) | **POST** /heatmap | Generate Heatmap
*HeatmapApi* | [**getHeatmapStatus**](docs/HeatmapApi.md#getHeatmapStatus) | **GET** /heatmap/{generationId} | Status - Generate Heatmap
*ImageTargetApi* | [**createImageTargets**](docs/ImageTargetApi.md#createImageTargets) | **POST** /targetCollection/{tcId}/targets | Create Image Targets
*ImageTargetApi* | [**deleteImageTarget**](docs/ImageTargetApi.md#deleteImageTarget) | **DELETE** /targetCollection/{tcId}/target/{targetId} | Delete Image Target
*ImageTargetApi* | [**getImageTarget**](docs/ImageTargetApi.md#getImageTarget) | **GET** /targetCollection/{tcId}/target/{targetId} | Get Image Target
*ImageTargetApi* | [**getImageTargetStatus**](docs/ImageTargetApi.md#getImageTargetStatus) | **GET** /targetCollection/{tcId}/generation/targets/{generationId} | Status - Image Targets Creation
*ImageTargetApi* | [**getImageTargets**](docs/ImageTargetApi.md#getImageTargets) | **GET** /targetCollection/{tcId}/target | Get Image Targets
*ImageTargetApi* | [**updateImageTarget**](docs/ImageTargetApi.md#updateImageTarget) | **POST** /targetCollection/{tcId}/target/{targetId} | Update Image Target
*ImageTargetCollectionApi* | [**createImageTargetCollection**](docs/ImageTargetCollectionApi.md#createImageTargetCollection) | **POST** /targetCollection | Create Image Target Collection
*ImageTargetCollectionApi* | [**deleteImageTargetCollection**](docs/ImageTargetCollectionApi.md#deleteImageTargetCollection) | **DELETE** /targetCollection/{tcId} | Delete Image Target Collection
*ImageTargetCollectionApi* | [**generateCloudArchive**](docs/ImageTargetCollectionApi.md#generateCloudArchive) | **POST** /targetCollection/{tcId}/generation/cloudarchive | Generate Cloud Archive
*ImageTargetCollectionApi* | [**generateWTC**](docs/ImageTargetCollectionApi.md#generateWTC) | **POST** /targetCollection/{tcId}/generation/wtc | Generate WTC
*ImageTargetCollectionApi* | [**getCloudArchiveStatus**](docs/ImageTargetCollectionApi.md#getCloudArchiveStatus) | **GET** /targetCollection/{tcId}/generation/cloudarchive/{generationId} | Status - Generate Cloud Archive
*ImageTargetCollectionApi* | [**getImageTargetCollection**](docs/ImageTargetCollectionApi.md#getImageTargetCollection) | **GET** /targetCollection/{tcId} | Get Image Target Collection
*ImageTargetCollectionApi* | [**getImageTargetCollections**](docs/ImageTargetCollectionApi.md#getImageTargetCollections) | **GET** /targetCollection | Get all Image Target Collections
*ImageTargetCollectionApi* | [**getSimilarityCheckStatus**](docs/ImageTargetCollectionApi.md#getSimilarityCheckStatus) | **GET** /targetCollection/{tcId}/similarity/{generationId} | Status - Similarity Check
*ImageTargetCollectionApi* | [**getWTCStatus**](docs/ImageTargetCollectionApi.md#getWTCStatus) | **GET** /targetCollection/{tcId}/generation/wtc/{generationId} | Status - Generate WTC
*ImageTargetCollectionApi* | [**similarityCheck**](docs/ImageTargetCollectionApi.md#similarityCheck) | **POST** /targetCollection/{tcId}/similarity | Similarity Check
*ImageTargetCollectionApi* | [**updateImageTargetCollection**](docs/ImageTargetCollectionApi.md#updateImageTargetCollection) | **POST** /targetCollection/{tcId} | Update Image Target Collection
*ObjectTargetApi* | [**createObjectTargetFromImages**](docs/ObjectTargetApi.md#createObjectTargetFromImages) | **POST** /objectTargetCollection/{tcId}/target/images | Create Object Target from Images
*ObjectTargetApi* | [**createObjectTargetFromWTO**](docs/ObjectTargetApi.md#createObjectTargetFromWTO) | **POST** /objectTargetCollection/{tcId}/target/wto | Create Object Target from WTO
*ObjectTargetApi* | [**deleteObjectTarget**](docs/ObjectTargetApi.md#deleteObjectTarget) | **DELETE** /objectTargetCollection/{tcId}/target/{targetId} | Delete Object Target
*ObjectTargetApi* | [**extendObjectTarget**](docs/ObjectTargetApi.md#extendObjectTarget) | **PUT** /objectTargetCollection/{tcId}/target/{targetId} | Extend Object Target
*ObjectTargetApi* | [**getObjectTarget**](docs/ObjectTargetApi.md#getObjectTarget) | **GET** /objectTargetCollection/{tcId}/target/{targetId} | Get Object Target
*ObjectTargetApi* | [**getObjectTargetStatus**](docs/ObjectTargetApi.md#getObjectTargetStatus) | **GET** /objectTargetCollection/{tcId}/generation/targets/{generationId} | Status - Object Target Generation Information
*ObjectTargetApi* | [**getObjectTargets**](docs/ObjectTargetApi.md#getObjectTargets) | **GET** /objectTargetCollection/{tcId}/target | Get Object Targets
*ObjectTargetApi* | [**renameObjectTarget**](docs/ObjectTargetApi.md#renameObjectTarget) | **PUT** /objectTargetCollection/{tcId}/target/{targetId}/name | Rename Object Target
*ObjectTargetCollectionApi* | [**createObjectTargetCollection**](docs/ObjectTargetCollectionApi.md#createObjectTargetCollection) | **POST** /objectTargetCollection | Create Object Target Collection
*ObjectTargetCollectionApi* | [**deleteObjectTargetCollection**](docs/ObjectTargetCollectionApi.md#deleteObjectTargetCollection) | **DELETE** /objectTargetCollection/{tcId} | Delete Object Target Collection
*ObjectTargetCollectionApi* | [**generateWTO**](docs/ObjectTargetCollectionApi.md#generateWTO) | **POST** /objectTargetCollection/{tcId}/generation/wto | Generate WTO
*ObjectTargetCollectionApi* | [**getObjectTargetCollection**](docs/ObjectTargetCollectionApi.md#getObjectTargetCollection) | **GET** /objectTargetCollection/{tcId} | Get Object Target Collection
*ObjectTargetCollectionApi* | [**getObjectTargetCollectionStatus**](docs/ObjectTargetCollectionApi.md#getObjectTargetCollectionStatus) | **GET** /objectTargetCollection/{tcId}/jobs | Status - Get Object Target Collection jobs
*ObjectTargetCollectionApi* | [**getObjectTargetCollections**](docs/ObjectTargetCollectionApi.md#getObjectTargetCollections) | **GET** /objectTargetCollection | Get all Object Target Collections
*ObjectTargetCollectionApi* | [**getWTOStatus**](docs/ObjectTargetCollectionApi.md#getWTOStatus) | **GET** /objectTargetCollection/{tcId}/generation/wto/{generationId} | Status - Generate WTO
*ObjectTargetCollectionApi* | [**updateObjectTargetCollection**](docs/ObjectTargetCollectionApi.md#updateObjectTargetCollection) | **PUT** /objectTargetCollection/{tcId} | Update Object Target Collection
*ProjectApi* | [**getProjects**](docs/ProjectApi.md#getProjects) | **GET** /projects | Get all projects


## Documentation for Models

 - [CloudArchiveGenerationResponse](docs/CloudArchiveGenerationResponse.md)
 - [CloudArchiveGenerationResponseInputParams](docs/CloudArchiveGenerationResponseInputParams.md)
 - [CreateImageTargetCollectionBody](docs/CreateImageTargetCollectionBody.md)
 - [CreateImageTargetCollectionBodyCloudArchive](docs/CreateImageTargetCollectionBodyCloudArchive.md)
 - [CreateImageTargetsBody](docs/CreateImageTargetsBody.md)
 - [CreateImageTargetsResponse](docs/CreateImageTargetsResponse.md)
 - [CreateImageTargetsResponseInputParams](docs/CreateImageTargetsResponseInputParams.md)
 - [CreateImageTargetsResponseInputParamsTargets](docs/CreateImageTargetsResponseInputParamsTargets.md)
 - [CreateObjectTargetCollectionBody](docs/CreateObjectTargetCollectionBody.md)
 - [CreateObjectTargetImagesBody](docs/CreateObjectTargetImagesBody.md)
 - [CreateObjectTargetImagesBodyResource](docs/CreateObjectTargetImagesBodyResource.md)
 - [CreateObjectTargetWTOBody](docs/CreateObjectTargetWTOBody.md)
 - [CreateObjectTargetWTOBodyResource](docs/CreateObjectTargetWTOBodyResource.md)
 - [ExtendObjectTargetBody](docs/ExtendObjectTargetBody.md)
 - [GenerateHeatmapBody](docs/GenerateHeatmapBody.md)
 - [GenerateHeatmapResponse](docs/GenerateHeatmapResponse.md)
 - [GenerateHeatmapResponseInputParams](docs/GenerateHeatmapResponseInputParams.md)
 - [GenerateHeatmapStatusResponse](docs/GenerateHeatmapStatusResponse.md)
 - [GenerateHeatmapStatusResponsePayload](docs/GenerateHeatmapStatusResponsePayload.md)
 - [GenerateWTCBody](docs/GenerateWTCBody.md)
 - [GenerateWTCStatusResponse](docs/GenerateWTCStatusResponse.md)
 - [GenerateWTOBody](docs/GenerateWTOBody.md)
 - [GetAccountInfoResponse](docs/GetAccountInfoResponse.md)
 - [GetAccountInfoResponseStorage](docs/GetAccountInfoResponseStorage.md)
 - [ImageTargetCollectionResponse](docs/ImageTargetCollectionResponse.md)
 - [ImageTargetCollectionResponseCloudArchive](docs/ImageTargetCollectionResponseCloudArchive.md)
 - [ImageTargetCollectionResponseWtc](docs/ImageTargetCollectionResponseWtc.md)
 - [ImageTargetResponse](docs/ImageTargetResponse.md)
 - [ObjectTargetCollectionJobResponse](docs/ObjectTargetCollectionJobResponse.md)
 - [ObjectTargetCollectionResponse](docs/ObjectTargetCollectionResponse.md)
 - [ObjectTargetCollectionResponseWto](docs/ObjectTargetCollectionResponseWto.md)
 - [ObjectTargetJobResponse](docs/ObjectTargetJobResponse.md)
 - [ObjectTargetResponse](docs/ObjectTargetResponse.md)
 - [ObjectTargetResponseResource](docs/ObjectTargetResponseResource.md)
 - [ObjectTargetResponseWtoFile](docs/ObjectTargetResponseWtoFile.md)
 - [RenameObjectTargetBody](docs/RenameObjectTargetBody.md)
 - [SimilarityCheckBody](docs/SimilarityCheckBody.md)
 - [SimilarityCheckBodyImages](docs/SimilarityCheckBodyImages.md)
 - [SimilarityCheckResponse](docs/SimilarityCheckResponse.md)
 - [SimilarityCheckResponseInputParams](docs/SimilarityCheckResponseInputParams.md)
 - [SimilarityCheckResponseInputParamsImages](docs/SimilarityCheckResponseInputParamsImages.md)
 - [SimilarityCheckStatusResponse](docs/SimilarityCheckStatusResponse.md)
 - [SimilarityCheckStatusResponseCandidates](docs/SimilarityCheckStatusResponseCandidates.md)
 - [SimilarityCheckStatusResponseInputParams](docs/SimilarityCheckStatusResponseInputParams.md)
 - [SimilarityCheckStatusResponsePayload](docs/SimilarityCheckStatusResponsePayload.md)
 - [UpdateImageTargetBody](docs/UpdateImageTargetBody.md)
 - [UpdateImageTargetCollectionBody](docs/UpdateImageTargetCollectionBody.md)
 - [UpdateObjectTargetCollectionBody](docs/UpdateObjectTargetCollectionBody.md)


## Documentation for Authorization

All endpoints do not require authorization.
Authentication schemes defined for the API:

## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author



