# HeatmapApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

Method | HTTP request | Description
------------- | ------------- | -------------
[**generateHeatmap**](HeatmapApi.md#generateHeatmap) | **POST** /heatmap | Generate Heatmap
[**getHeatmapStatus**](HeatmapApi.md#getHeatmapStatus) | **GET** /heatmap/{generationId} | Status - Generate Heatmap


<a name="generateHeatmap"></a>
# **generateHeatmap**
> GenerateHeatmapResponse generateHeatmap(xVersion, xToken, contentType, generateHeatmapBody)

Generate Heatmap

Generates a greyscale image out of the input image, where areas with recognition and tracking relevance are highlighted in color. This way one can better understand the rating of an image and see which areas have the highest importance for 2D recognition and tracking. Note that only JPG and non-transparent PNG files are accepted and the generated heatmap image is stored on a temporary folder which is deleted after 24 hours. Store the image on your own server in case you plan to use it in your user interface. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.HeatmapApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://api-eu.wikitude.com/cloudrecognition");

    HeatmapApi apiInstance = new HeatmapApi(defaultClient);
    String xVersion = "3"; // String | The version of the API to be used. Must be set to 3.
    String xToken = "xToken_example"; // String | Your Manager Token.
    String contentType = "contentType_example"; // String | The Content Type of the body. Must be set to application/json.
    GenerateHeatmapBody generateHeatmapBody = new GenerateHeatmapBody(); // GenerateHeatmapBody | 
    try {
      GenerateHeatmapResponse result = apiInstance.generateHeatmap(xVersion, xToken, contentType, generateHeatmapBody);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling HeatmapApi#generateHeatmap");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xVersion** | **String**| The version of the API to be used. Must be set to 3. |
 **xToken** | **String**| Your Manager Token. |
 **contentType** | **String**| The Content Type of the body. Must be set to application/json. |
 **generateHeatmapBody** | [**GenerateHeatmapBody**](GenerateHeatmapBody.md)|  |

### Return type

[**GenerateHeatmapResponse**](GenerateHeatmapResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | successful operation |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR |  -  |

<a name="getHeatmapStatus"></a>
# **getHeatmapStatus**
> GenerateHeatmapStatusResponse getHeatmapStatus(xVersion, xToken, generationId)

Status - Generate Heatmap

Retrieves information status about a particular scheduled heatmap creation.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.HeatmapApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://api-eu.wikitude.com/cloudrecognition");

    HeatmapApi apiInstance = new HeatmapApi(defaultClient);
    String xVersion = "3"; // String | The version of the API to be used. Must be set to 3.
    String xToken = "xToken_example"; // String | Your Manager Token.
    String generationId = "generationId_example"; // String | Unique identifier of the asynchronous job created by a generation endpoint.
    try {
      GenerateHeatmapStatusResponse result = apiInstance.getHeatmapStatus(xVersion, xToken, generationId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling HeatmapApi#getHeatmapStatus");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xVersion** | **String**| The version of the API to be used. Must be set to 3. |
 **xToken** | **String**| Your Manager Token. |
 **generationId** | **String**| Unique identifier of the asynchronous job created by a generation endpoint. |

### Return type

[**GenerateHeatmapStatusResponse**](GenerateHeatmapStatusResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The requested job information, including \&quot;status\&quot;, \&quot;payload\&quot; attribute, \&quot;estimatedEnd\&quot;, \&quot;estimatedLatency\&quot; attributes. The \&quot;payload\&quot; contains a url to the generated heatmap or or an \&quot;error\&quot;-object.  |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | GENERATION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

