# ImageTargetApi

All URIs are relative to *https://api-eu.wikitude.com/cloudrecognition*

Method | HTTP request | Description
------------- | ------------- | -------------
[**createImageTargets**](ImageTargetApi.md#createImageTargets) | **POST** /targetCollection/{tcId}/targets | Create Image Targets
[**deleteImageTarget**](ImageTargetApi.md#deleteImageTarget) | **DELETE** /targetCollection/{tcId}/target/{targetId} | Delete Image Target
[**getImageTarget**](ImageTargetApi.md#getImageTarget) | **GET** /targetCollection/{tcId}/target/{targetId} | Get Image Target
[**getImageTargetStatus**](ImageTargetApi.md#getImageTargetStatus) | **GET** /targetCollection/{tcId}/generation/targets/{generationId} | Status - Image Targets Creation
[**getImageTargets**](ImageTargetApi.md#getImageTargets) | **GET** /targetCollection/{tcId}/target | Get Image Targets
[**updateImageTarget**](ImageTargetApi.md#updateImageTarget) | **POST** /targetCollection/{tcId}/target/{targetId} | Update Image Target


<a name="createImageTargets"></a>
# **createImageTargets**
> CreateImageTargetsResponse createImageTargets(xVersion, xToken, contentType, tcId, createImageTargetsBody)

Create Image Targets

Create a set of up to 10 new Targets in a Target Collection in your account. The task to create the listed Targets is scheduled. The response body contains the initial job status. \&quot;Location\&quot;-header is the url to the GET endpoint that returns current job status information. It is recommended to query this endpoint after \&quot;estimatedLatency\&quot; milliseconds, and poll it afterwards every 10 seconds in case job status is still not \&quot;COMPLETED\&quot;. Once job status is \&quot;COMPLETED\&quot; each item holds a \&quot;target\&quot; attribute of the created target or an \&quot;error\&quot; attribute. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ImageTargetApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://api-eu.wikitude.com/cloudrecognition");

    ImageTargetApi apiInstance = new ImageTargetApi(defaultClient);
    String xVersion = "3"; // String | The version of the API to be used. Must be set to 3.
    String xToken = "xToken_example"; // String | Your Manager Token.
    String contentType = "contentType_example"; // String | The Content Type of the body. Must be set to application/json.
    String tcId = "tcId_example"; // String | Unique identifier of the Image Target Collection.
    List<CreateImageTargetsBody> createImageTargetsBody = Arrays.asList(); // List<CreateImageTargetsBody> | 
    try {
      CreateImageTargetsResponse result = apiInstance.createImageTargets(xVersion, xToken, contentType, tcId, createImageTargetsBody);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ImageTargetApi#createImageTargets");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xVersion** | **String**| The version of the API to be used. Must be set to 3. |
 **xToken** | **String**| Your Manager Token. |
 **contentType** | **String**| The Content Type of the body. Must be set to application/json. |
 **tcId** | **String**| Unique identifier of the Image Target Collection. |
 **createImageTargetsBody** | [**List&lt;CreateImageTargetsBody&gt;**](CreateImageTargetsBody.md)|  | [optional]

### Return type

[**CreateImageTargetsResponse**](CreateImageTargetsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**202** | The job of the Target creation task. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; INVALID_PROPERTY&lt;br/&gt; DUPLICATE_TARGETIMAGE_USAGE  |  -  |
**401** | INVALID_TOKEN  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

<a name="deleteImageTarget"></a>
# **deleteImageTarget**
> deleteImageTarget(xVersion, xToken, tcId, targetId)

Delete Image Target

Delete a particular Target from your account.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ImageTargetApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://api-eu.wikitude.com/cloudrecognition");

    ImageTargetApi apiInstance = new ImageTargetApi(defaultClient);
    String xVersion = "3"; // String | The version of the API to be used. Must be set to 3.
    String xToken = "xToken_example"; // String | Your Manager Token.
    String tcId = "tcId_example"; // String | Unique identifier of the Image Target Collection.
    String targetId = "targetId_example"; // String | Unique identifier of the Image Target.
    try {
      apiInstance.deleteImageTarget(xVersion, xToken, tcId, targetId);
    } catch (ApiException e) {
      System.err.println("Exception when calling ImageTargetApi#deleteImageTarget");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xVersion** | **String**| The version of the API to be used. Must be set to 3. |
 **xToken** | **String**| Your Manager Token. |
 **tcId** | **String**| Unique identifier of the Image Target Collection. |
 **targetId** | **String**| Unique identifier of the Image Target. |

### Return type

null (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**204** | Successful operation - Empty response body. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

<a name="getImageTarget"></a>
# **getImageTarget**
> ImageTargetResponse getImageTarget(xVersion, xToken, tcId, targetId)

Get Image Target

Request a particular Image Target in a particular Target Collection.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ImageTargetApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://api-eu.wikitude.com/cloudrecognition");

    ImageTargetApi apiInstance = new ImageTargetApi(defaultClient);
    String xVersion = "3"; // String | The version of the API to be used. Must be set to 3.
    String xToken = "xToken_example"; // String | Your Manager Token.
    String tcId = "tcId_example"; // String | Unique identifier of the Image Target Collection.
    String targetId = "targetId_example"; // String | Unique identifier of the Image Target.
    try {
      ImageTargetResponse result = apiInstance.getImageTarget(xVersion, xToken, tcId, targetId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ImageTargetApi#getImageTarget");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xVersion** | **String**| The version of the API to be used. Must be set to 3. |
 **xToken** | **String**| Your Manager Token. |
 **tcId** | **String**| Unique identifier of the Image Target Collection. |
 **targetId** | **String**| Unique identifier of the Image Target. |

### Return type

[**ImageTargetResponse**](ImageTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The particular requested Target. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

<a name="getImageTargetStatus"></a>
# **getImageTargetStatus**
> CreateImageTargetsResponse getImageTargetStatus(xVersion, xToken, tcId, generationId)

Status - Image Targets Creation

Retrieves information status about a particular scheduled targets creation.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ImageTargetApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://api-eu.wikitude.com/cloudrecognition");

    ImageTargetApi apiInstance = new ImageTargetApi(defaultClient);
    String xVersion = "3"; // String | The version of the API to be used. Must be set to 3.
    String xToken = "xToken_example"; // String | Your Manager Token.
    String tcId = "tcId_example"; // String | Unique identifier of the Image Target Collection.
    String generationId = "generationId_example"; // String | Unique identifier of the asynchronous job created by a generation endpoint.
    try {
      CreateImageTargetsResponse result = apiInstance.getImageTargetStatus(xVersion, xToken, tcId, generationId);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ImageTargetApi#getImageTargetStatus");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xVersion** | **String**| The version of the API to be used. Must be set to 3. |
 **xToken** | **String**| Your Manager Token. |
 **tcId** | **String**| Unique identifier of the Image Target Collection. |
 **generationId** | **String**| Unique identifier of the asynchronous job created by a generation endpoint. |

### Return type

[**CreateImageTargetsResponse**](CreateImageTargetsResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The requested job information, including \&quot;status\&quot;, \&quot;payload\&quot; attribute, \&quot;estimatedEnd\&quot;, \&quot;estimatedLatency\&quot; attributes. The \&quot;payload\&quot; contains a list of \&quot;creation-items\&quot;. Every item has an \&quot;input\&quot;-attribute that holds the JSON-Object used for creation (equals item at this index in post-body). Once status is \&quot;COMPLETED\&quot; every item also contains a \&quot;target\&quot;-attribute (same style as in successful single target creation) or an \&quot;error\&quot;-object (same as status 400 error JSON response in single target creation).  |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | GENERATION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

<a name="getImageTargets"></a>
# **getImageTargets**
> List&lt;ImageTargetResponse&gt; getImageTargets(xVersion, xToken, tcId, sortby, sortorder, skip, limit, s, addHasAugmentations)

Get Image Targets

Request all Image Targets in a Target Collection.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ImageTargetApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://api-eu.wikitude.com/cloudrecognition");

    ImageTargetApi apiInstance = new ImageTargetApi(defaultClient);
    String xVersion = "3"; // String | The version of the API to be used. Must be set to 3.
    String xToken = "xToken_example"; // String | Your Manager Token.
    String tcId = "tcId_example"; // String | Unique identifier of the Image Target Collection.
    String sortby = "sortby_example"; // String | Targets may be sorted by 'name', 'creDat', 'modDat', 'rating'. Default value: 'creDat'
    String sortorder = "sortorder_example"; // String | Targets may be sorted ascending ('asc') or descending ('desc'). Default value: 'desc'
    BigDecimal skip = new BigDecimal(78); // BigDecimal | Set 0 to start with first target, set e.g. to 2 to skip first 2 targets. Default value: 0
    BigDecimal limit = new BigDecimal(78); // BigDecimal | Set to 0 for 'all targets' or use positive value to define max. amount of targets to return. Default value: 0
    String s = "s_example"; // String | The search string to look for in target names.
    Boolean addHasAugmentations = true; // Boolean | Add the hasAugmentations property.
    try {
      List<ImageTargetResponse> result = apiInstance.getImageTargets(xVersion, xToken, tcId, sortby, sortorder, skip, limit, s, addHasAugmentations);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ImageTargetApi#getImageTargets");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xVersion** | **String**| The version of the API to be used. Must be set to 3. |
 **xToken** | **String**| Your Manager Token. |
 **tcId** | **String**| Unique identifier of the Image Target Collection. |
 **sortby** | **String**| Targets may be sorted by &#39;name&#39;, &#39;creDat&#39;, &#39;modDat&#39;, &#39;rating&#39;. Default value: &#39;creDat&#39; | [optional]
 **sortorder** | **String**| Targets may be sorted ascending (&#39;asc&#39;) or descending (&#39;desc&#39;). Default value: &#39;desc&#39; | [optional]
 **skip** | **BigDecimal**| Set 0 to start with first target, set e.g. to 2 to skip first 2 targets. Default value: 0 | [optional]
 **limit** | **BigDecimal**| Set to 0 for &#39;all targets&#39; or use positive value to define max. amount of targets to return. Default value: 0 | [optional]
 **s** | **String**| The search string to look for in target names. | [optional]
 **addHasAugmentations** | **Boolean**| Add the hasAugmentations property. | [optional]

### Return type

[**List&lt;ImageTargetResponse&gt;**](ImageTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The Array of Targets in the Target Collection. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID&lt;br/&gt; INVALID_QUERY_PARAMETER  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

<a name="updateImageTarget"></a>
# **updateImageTarget**
> ImageTargetResponse updateImageTarget(xVersion, xToken, contentType, tcId, targetId, updateImageTargetBody)

Update Image Target

Updates properties of a particular Target in your account. Currently following properties are supported: physicalHeight, metadata. 

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.models.*;
import org.openapitools.client.api.ImageTargetApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://api-eu.wikitude.com/cloudrecognition");

    ImageTargetApi apiInstance = new ImageTargetApi(defaultClient);
    String xVersion = "3"; // String | The version of the API to be used. Must be set to 3.
    String xToken = "xToken_example"; // String | Your Manager Token.
    String contentType = "contentType_example"; // String | The Content Type of the body. Must be set to application/json.
    String tcId = "tcId_example"; // String | Unique identifier of the Image Target Collection.
    String targetId = "targetId_example"; // String | Unique identifier of the Image Target.
    UpdateImageTargetBody updateImageTargetBody = new UpdateImageTargetBody(); // UpdateImageTargetBody | 
    try {
      ImageTargetResponse result = apiInstance.updateImageTarget(xVersion, xToken, contentType, tcId, targetId, updateImageTargetBody);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling ImageTargetApi#updateImageTarget");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **xVersion** | **String**| The version of the API to be used. Must be set to 3. |
 **xToken** | **String**| Your Manager Token. |
 **contentType** | **String**| The Content Type of the body. Must be set to application/json. |
 **tcId** | **String**| Unique identifier of the Image Target Collection. |
 **targetId** | **String**| Unique identifier of the Image Target. |
 **updateImageTargetBody** | [**UpdateImageTargetBody**](UpdateImageTargetBody.md)|  |

### Return type

[**ImageTargetResponse**](ImageTargetResponse.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | The updated Image Target. |  -  |
**400** | HEADER_PROPERTY_MISSING&lt;br/&gt; HEADER_PROPERTY_INVALID  |  -  |
**401** | INVALID_TOKEN  |  -  |
**404** | TARGET_COLLECTION_NOT_FOUND&lt;br/&gt; TARGET_NOT_FOUND  |  -  |
**500** | INTERNAL_SERVER_ERROR  |  -  |

